###########
Table class
###########

.. currentmodule:: ddbmock.database.table

.. autoclass:: Table

Constructors
============

__init__
--------

.. automethod:: Table.__init__

from_dict
---------

.. automethod:: Table.from_dict

Table manipulations
===================

truncate
--------

.. automethod:: Table.truncate

delete
------

.. automethod:: Table.delete

activate
--------

.. automethod:: Table.activate

update_throughput
-----------------

.. automethod:: Table.update_throughput

get_size
--------

.. automethod:: Table.get_size

to_dict
-------

.. automethod:: Table.to_dict

Items manipulations
===================

delete_item
-----------

.. automethod:: Table.delete_item

update_item
-----------

.. automethod:: Table.update_item

put
---

.. automethod:: Table.put

get
---

.. automethod:: Table.get

query
-----

.. automethod:: Table.query

scan
----

.. automethod:: Table.scan
